# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: control-server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63ontrol-server.proto\x12\x08scalebox\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\">\n\x06JobKey\x12\x11\n\tjob1_name\x18\x01 \x01(\t\x12\x10\n\x08key_text\x18\x02 \x01(\t\x12\x0f\n\x07job0_id\x18\x03 \x01(\x05\"K\n\x07JobKeys\x12\x15\n\rnext_job_name\x18\x01 \x01(\t\x12\x11\n\tkey_texts\x18\x02 \x03(\t\x12\x16\n\x0e\x63urrent_job_id\x18\x03 \x01(\x05\"#\n\x08TaskItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03key\x18\x02 \x01(\t\"9\n\x07\x43ommand\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x14\n\x0c\x63ommand_text\x18\x03 \x01(\t\"1\n\x0b\x43ommandList\x12\"\n\x07\x63ommand\x18\x01 \x03(\x0b\x32\x11.scalebox.Command\"\x88\x03\n\x0fTaskExecMessage\x12\x0c\n\x04slot\x18\x01 \x01(\x05\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07task_id\x18\x03 \x01(\x03\x12\x13\n\x0binput_bytes\x18\x04 \x01(\x03\x12\x14\n\x0coutput_bytes\x18\x05 \x01(\x03\x12&\n\x02t0\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t1\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t2\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t3\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02t4\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08time_arr\x18\x0b \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07sys_out\x18\x0c \x01(\t\x12\x0f\n\x07\x61pp_out\x18\r \x01(\t2\x8f\x08\n\nBoxService\x12\x42\n\x04\x45\x63ho\x12\x1c.google.protobuf.StringValue\x1a\x1c.google.protobuf.StringValue\x12>\n\x0bGetNextTask\x12\x1b.google.protobuf.Int32Value\x1a\x12.scalebox.TaskItem\x12J\n\x0eSetTaskStarted\x12\x1b.google.protobuf.Int64Value\x1a\x1b.google.protobuf.Int32Value\x12I\n\x0fSetTaskFinished\x12\x19.scalebox.TaskExecMessage\x1a\x1b.google.protobuf.Int32Value\x12M\n\x11SetSlotTerminated\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12\x44\n\x13GetRunnableSlotList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12N\n\x12SetSlotInitialized\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12\x46\n\x15GetTerminableSlotList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12\x46\n\x15GetRunnableWorkerList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12P\n\x14SetWorkerInitialized\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12H\n\x17GetTerminableWorkerList\x12\x16.google.protobuf.Empty\x1a\x15.scalebox.CommandList\x12O\n\x13SetWorkerTerminated\x12\x1b.google.protobuf.Int32Value\x1a\x1b.google.protobuf.Int32Value\x12>\n\rSendToNextJob\x12\x10.scalebox.JobKey\x1a\x1b.google.protobuf.Int32Value\x12\x44\n\x12SendMessagesToNext\x12\x11.scalebox.JobKeys\x1a\x1b.google.protobuf.Int32ValueB\x15\n\x11\x64\x65v.scalebox.gprcP\x01\x62\x06proto3')



_JOBKEY = DESCRIPTOR.message_types_by_name['JobKey']
_JOBKEYS = DESCRIPTOR.message_types_by_name['JobKeys']
_TASKITEM = DESCRIPTOR.message_types_by_name['TaskItem']
_COMMAND = DESCRIPTOR.message_types_by_name['Command']
_COMMANDLIST = DESCRIPTOR.message_types_by_name['CommandList']
_TASKEXECMESSAGE = DESCRIPTOR.message_types_by_name['TaskExecMessage']
JobKey = _reflection.GeneratedProtocolMessageType('JobKey', (_message.Message,), {
  'DESCRIPTOR' : _JOBKEY,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.JobKey)
  })
_sym_db.RegisterMessage(JobKey)

JobKeys = _reflection.GeneratedProtocolMessageType('JobKeys', (_message.Message,), {
  'DESCRIPTOR' : _JOBKEYS,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.JobKeys)
  })
_sym_db.RegisterMessage(JobKeys)

TaskItem = _reflection.GeneratedProtocolMessageType('TaskItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKITEM,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.TaskItem)
  })
_sym_db.RegisterMessage(TaskItem)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
  'DESCRIPTOR' : _COMMAND,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.Command)
  })
_sym_db.RegisterMessage(Command)

CommandList = _reflection.GeneratedProtocolMessageType('CommandList', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDLIST,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.CommandList)
  })
_sym_db.RegisterMessage(CommandList)

TaskExecMessage = _reflection.GeneratedProtocolMessageType('TaskExecMessage', (_message.Message,), {
  'DESCRIPTOR' : _TASKEXECMESSAGE,
  '__module__' : 'control_server_pb2'
  # @@protoc_insertion_point(class_scope:scalebox.TaskExecMessage)
  })
_sym_db.RegisterMessage(TaskExecMessage)

_BOXSERVICE = DESCRIPTOR.services_by_name['BoxService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021dev.scalebox.gprcP\001'
  _JOBKEY._serialized_start=128
  _JOBKEY._serialized_end=190
  _JOBKEYS._serialized_start=192
  _JOBKEYS._serialized_end=267
  _TASKITEM._serialized_start=269
  _TASKITEM._serialized_end=304
  _COMMAND._serialized_start=306
  _COMMAND._serialized_end=363
  _COMMANDLIST._serialized_start=365
  _COMMANDLIST._serialized_end=414
  _TASKEXECMESSAGE._serialized_start=417
  _TASKEXECMESSAGE._serialized_end=809
  _BOXSERVICE._serialized_start=812
  _BOXSERVICE._serialized_end=1851
# @@protoc_insertion_point(module_scope)
